@@ -1,7 +1,7 @@
 from ._get_logger import logger
 from .hooks import *
 from .lr_scheduler import LRWarmupScheduler
-from .utils import HistoryBuffer, misc
+from .utils import HistoryBuffer, misc, metric
 from .trainer import Trainer, MetricStorage
 from .ddp_trainer import DDPTrainer
 
