@@ -1,4 +1,4 @@
 from .checkpoint_hook import CheckpointerHook
-from .eval_hook import EvalHook
+from .eval_hook import EvalHook, EvalTotalHook
 from .hookbase import HookBase
 from .logger_hook import LoggerHook
